@@ -1,5 +1,22 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
+#
+# Python kontocheck package
+#
+# Copyright (c) 2013 by joonis new media <thimo.kraemer@joonis.de>
+# 
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 3.0 of the License, or (at your option) any later version.
+# 
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+# 
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library.
 
 """Python ctypes wrapper of the konto_check library.
 
@@ -26,11 +43,11 @@ from ctypes import c_char_p, c_int, c_void_p, create_string_buffer, \
                     POINTER, byref, CDLL, util, cast
 c_int_p = POINTER(c_int)
 
-__version__ = '5.2.1'
+__version__ = '5.3.0'
 
-__all__ = ['get_version', 'cleanup', 'lut_load', 'lut_is_valid',
-            'get_name', 'get_postalcode', 'get_city', 'get_bic',
-            'check_iban', 'create_iban', 'KontoCheckError']
+__all__ = ['get_version', 'lut_load', 'lut_is_valid', 'cleanup',
+            'check_iban', 'create_iban', 'get_bic', 'get_name',
+            'get_postalcode', 'get_city', 'KontoCheckError']
 
 
 # Get the path to the default lut file
@@ -43,6 +60,9 @@ _PY_BIT = struct.calcsize('P') * 8
 
 
 class KontoCheckError(Exception):
+    """
+    The konto_check library returned an error.
+    """
 
     # Die IBAN-Prüfsumme stimmt, für die Bank gibt es allerdings eine (andere) Nachfolge-BLZ
     IBAN_CHKSUM_OK_NACHFOLGE_BLZ_DEFINED = -140
@@ -459,7 +479,8 @@ libkontocheck = CDLL(libpath)
 libkontocheck.get_kto_check_version.restype = c_char_p
 libkontocheck.get_kto_check_version.argtypes = None
 def get_version():
-    """Get the version of compiled konto_check library.
+    """
+    Get the version of the compiled konto_check library.
     """
     return libkontocheck.get_kto_check_version()
 
@@ -504,7 +525,9 @@ libkontocheck.kto_check_encoding(2)
 libkontocheck.lut_cleanup.restype = c_void_p
 libkontocheck.lut_cleanup.argtypes = None
 def cleanup():
-    """Reset and free all loaded LUT data.
+    """
+    Reset and free all loaded LUT data.
+    
     It is called by default when the program exits.
     """
     return libkontocheck.lut_cleanup()
@@ -530,8 +553,10 @@ atexit.register(cleanup)
 libkontocheck.lut_init.restype = c_int
 libkontocheck.lut_init.argtypes = (c_char_p, c_int, c_int)
 def lut_load(field_set=5, path=None):
-    """Load the given field set from a LUT file specified by *path*,
-    that points to the shipped LUT file by default.
+    """
+    Load the given field set from a LUT file specified by *path*.
+    
+    If *path* is omitted or *None* the shipped LUT file is used.
     
     Available field sets (default is 5):
     
@@ -580,7 +605,9 @@ def lut_load(field_set=5, path=None):
 libkontocheck.lut_valid.restype = c_int
 libkontocheck.lut_valid.argtypes = None
 def lut_is_valid():
-    """Check if the current LUT file is valid.
+    """
+    Check if the current LUT file is valid.
+    
     If this function returns *False*, you should update the LUT file
     and/or the whole kontocheck library.
     
@@ -619,9 +646,13 @@ libkontocheck.lut_name_kurz.restype = c_char_p
 libkontocheck.lut_name_kurz.argtypes = (c_char_p, c_int, c_int_p)
 
 def get_name(bankcode, short_form=False):
-    """Get the name of a bank by a given bankcode (or German IBAN).
+    """
+    Get the name of a bank by a given bankcode (or German IBAN).
+    
     Returns the short or long version of the name.
     """
+    if bankcode.startswith('DE'):
+        bankcode = bankcode[4:12]
     retval = c_int()
     if short_form:
         name = libkontocheck.lut_name_kurz(bankcode, 0, byref(retval))
@@ -661,7 +692,8 @@ def get_postalcode(bankcode):
 libkontocheck.lut_ort.restype = c_char_p
 libkontocheck.lut_ort.argtypes = (c_char_p, c_int, c_int_p)
 def get_city(bankcode):
-    """Get the city of a bank by a given bankcode (or German IBAN).
+    """
+    Get the city of a bank by a given bankcode (or German IBAN).
     """
     if bankcode.startswith('DE'):
         bankcode = bankcode[4:12]
@@ -699,7 +731,8 @@ def get_city(bankcode):
 libkontocheck.iban2bic.restype = c_char_p
 libkontocheck.iban2bic.argtypes = (c_char_p, c_int_p, c_char_p, c_char_p)
 def get_bic(iban):
-    """Get the corresponding BIC to a given IBAN. 
+    """
+    Get the corresponding BIC to a given IBAN. 
     """
     retval = c_int()
     bankcode = create_string_buffer(9)
@@ -726,7 +759,8 @@ def get_bic(iban):
 libkontocheck.iban_check.restype = c_int
 libkontocheck.iban_check.argtypes = (c_char_p, c_int_p)
 def check_iban(iban, error=False):
-    """Check an IBAN for validity.
+    """
+    Check an IBAN for validity.
     
     For German IBANs also the check digit of the account number is
     verified. If *error* is set to *True*, an exception is raised
@@ -819,8 +853,10 @@ libkontocheck.iban_bic_gen.restype = c_void_p # c_char_p
 libkontocheck.iban_bic_gen.argtypes = (c_char_p, c_char_p,
                 POINTER(c_char_p), c_char_p, c_char_p, c_int_p)
 def create_iban(bankcode, account, get_bic=False):
-    """Create a valid IBAN by given bank code and account.
-    If *get_bic* is *True*, a tupel of (iban, bic) is returned.
+    """
+    Create a valid IBAN by given bank code and account.
+    
+    If *get_bic* evaluates to *True*, a 2-tupel of (IBAN, BIC) is returned.
     """
     bic = c_char_p('\0'*12)
     bankcode2 = create_string_buffer(9)
